@@ -66,9 +66,13 @@ class Settings:
     def FLAVIUS_API_DATA_DELETE(self):
         return getattr(settings, "FLAVIUS_API_DATA_DELETE", 'api/data_delete.php')
 
+    @property
+    def FLAVIUS_API_ORDER_DECIDE(self):
+        return getattr(settings, "FLAVIUS_API_DATA_DELETE", 'api/order_decide.php')
+
     @property
     def FLAVIUS_API_PAGE_FETCH(self):
-        return getattr(settings, "FLAVIUS_API_PAGE_FETCH", 'api/pages.php')
+        return getattr(settings, "FLAVIUS_API_ORDER_DECIDE", 'api/pages.php')
 
     @property
     def EXCLUDE_TAX(self):
